@@ -15,7 +15,7 @@ public:
     explicit ServerSieveListWidgetItem(QListWidget *parent = nullptr);
     ~ServerSieveListWidgetItem() override;
 
-    Q_REQUIRED_RESULT SieveEditorUtil::SieveServerConfig serverConfig() const;
+    [[nodiscard]] SieveEditorUtil::SieveServerConfig serverConfig() const;
     void setServerConfig(const SieveEditorUtil::SieveServerConfig &conf);
 
 private:
@@ -38,7 +38,7 @@ public Q_SLOTS:
     void modifyServerConfig();
 
 private:
-    void slotReadServerSieveConfigDone(const QVector<SieveEditorUtil::SieveServerConfig> &lstConfig);
+    void slotReadServerSieveConfigDone(const QList<SieveEditorUtil::SieveServerConfig> &lstConfig);
     void deletePasswords();
     QStringList mNeedToRemovePasswordInWallet;
 };
