@@ -17,10 +17,10 @@ public:
     ~SieveEditorManageSieveWidget() override;
 
 protected:
-    Q_REQUIRED_RESULT bool refreshList() override;
+    [[nodiscard]] bool refreshList() override;
     void updateSieveSettings() override;
 
 private:
-    void slotReadServerSieveConfigDone(const QVector<SieveEditorUtil::SieveServerConfig> &lstConfig);
-    QVector<SieveEditorUtil::SieveServerConfig> mSieveServerSettings;
+    void slotReadServerSieveConfigDone(const QList<SieveEditorUtil::SieveServerConfig> &lstConfig);
+    QList<SieveEditorUtil::SieveServerConfig> mSieveServerSettings;
 };
