@@ -6,7 +6,7 @@
 
 #include "sieveeditorpagewidget.h"
 #include "sieveeditorglobalconfig.h"
-#include <KSieveUi/CheckScriptJob>
+#include <KSieveCore/CheckScriptJob>
 
 #include <KManageSieve/SieveJob>
 
@@ -41,8 +41,8 @@ void SieveEditorPageWidget::slotCheckSyntaxClicked()
     }
     mSieveEditorWidget->addNormalMessage(i18n("Uploading script to server for checking it, please wait..."));
 
-    auto checkScriptJob = new KSieveUi::CheckScriptJob(this);
-    connect(checkScriptJob, &KSieveUi::CheckScriptJob::finished, this, &SieveEditorPageWidget::slotCheckScriptJobFinished);
+    auto checkScriptJob = new KSieveCore::CheckScriptJob(this);
+    connect(checkScriptJob, &KSieveCore::CheckScriptJob::finished, this, &SieveEditorPageWidget::slotCheckScriptJobFinished);
     checkScriptJob->setUrl(mCurrentURL);
     checkScriptJob->setIsActive(mWasActive);
     checkScriptJob->setCurrentScript(script);
@@ -132,7 +132,7 @@ void SieveEditorPageWidget::slotPutResult(KManageSieve::SieveJob *job, bool succ
     }
     if (success) {
         if (job->property("showuploadinformation").toBool()) {
-            KMessageBox::information(this, i18n("The Sieve script was successfully uploaded."), i18n("Sieve Script Upload"));
+            KMessageBox::information(this, i18n("The Sieve script was successfully uploaded."), i18nc("@title:window", "Sieve Script Upload"));
         }
         mIsNewScript = false;
         mSieveEditorWidget->updateOriginalScript();
@@ -148,12 +148,12 @@ void SieveEditorPageWidget::slotPutResult(KManageSieve::SieveJob *job, bool succ
                                i18n("Uploading the Sieve script failed.\n"
                                     "The server responded:\n%1",
                                     msg),
-                               i18n("Sieve Error"));
+                               i18nc("@title:window", "Sieve Error"));
         } else {
             KMessageBox::error(this,
                                i18n("Uploading the Sieve script failed.\n"
                                     "unknown reason\n"),
-                               i18n("Sieve Error"));
+                               i18nc("@title:window", "Sieve Error"));
         }
     }
 }
@@ -164,7 +164,7 @@ bool SieveEditorPageWidget::needToSaveScript()
     if (mIsNewScript) {
         const int resultQuestion = KMessageBox::warningTwoActionsCancel(this,
                                                                         i18n("Script '%1' is new. Do you want to save it?", mCurrentURL.fileName()),
-                                                                        i18n("Save Script"),
+                                                                        i18nc("@title:window", "Save Script"),
                                                                         KStandardGuiItem::save(),
                                                                         KStandardGuiItem::discard());
         if (resultQuestion == KMessageBox::ButtonCode::PrimaryAction) {
@@ -177,7 +177,7 @@ bool SieveEditorPageWidget::needToSaveScript()
         if (mSieveEditorWidget->isModified()) {
             const int resultQuestion = KMessageBox::warningTwoActionsCancel(this,
                                                                             i18n("Script '%1' was changed. Do you want to save it ?", mCurrentURL.fileName()),
-                                                                            i18n("Save Script"),
+                                                                            i18nc("@title:window", "Save Script"),
                                                                             KStandardGuiItem::save(),
                                                                             KStandardGuiItem::discard());
             if (resultQuestion == KMessageBox::ButtonCode::PrimaryAction) {
@@ -390,3 +390,5 @@ QUrl SieveEditorPageWidget::currentHelpUrl() const
 {
     return mSieveEditorWidget->currentHelpUrl();
 }
+
+#include "moc_sieveeditorpagewidget.cpp"
